pub struct ShellCapability {
pub args: Vec<String>,
}Expand description
One entry in [shell.capabilities] — a command and its argument names.
Fields
args: Vec<String>Trait Implementations
Sourceimpl Clone for ShellCapability
impl Clone for ShellCapability
Sourcefn clone(&self) -> ShellCapability
fn clone(&self) -> ShellCapability
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellCapability
impl Debug for ShellCapability
Sourceimpl Default for ShellCapability
impl Default for ShellCapability
Sourcefn default() -> ShellCapability
fn default() -> ShellCapability
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ShellCapability
impl<'de> Deserialize<'de> for ShellCapability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellCapability
impl JsonSchema for ShellCapability
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ShellCapability
impl PartialEq for ShellCapability
Sourceimpl Serialize for ShellCapability
impl Serialize for ShellCapability
impl StructuralPartialEq for ShellCapability